@@ -1,9 +1,9 @@
 package Complete::Util;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-01-13'; # DATE
+our $DATE = '2020-01-28'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.608'; # VERSION
+our $VERSION = '0.609'; # VERSION
 
 use 5.010001;
 use strict;
@@ -713,8 +713,7 @@ sub complete_comma_sep {
     {
         last unless @$cae_res == 1;
         last if @$remaining_elems <= 1;
-        $cae_res->[0] .= $sep;
-        ununiquify_answer(answer => $cae_res);
+        $cae_res = [{word=>"$cae_res->[0]$sep", is_partial=>1}];
     }
     $cae_res;
 }
@@ -886,6 +885,7 @@ _
     result => {
         schema => 'undef',
     },
+    tags => ['hidden'],
 };
 sub ununiquify_answer {
     my %args = @_;
@@ -914,7 +914,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.608 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-13.
+This document describes version 0.609 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
 
 =head1 DESCRIPTION
 
